from sqlalchemy import Column, func, ForeignKey
from sqlalchemy.orm import relationship
from sqlalchemy.dialects.postgresql import UUID, JSON, TIMESTAMP, TEXT
from uuid import uuid4
from sqlalchemy.ext.declarative import declarative_base

from .tasks import Task as TaskModel
from .task_results import TaskResult as TaskResultModel
from .task_statuses import TaskStatus as TaskStatusModel

Base = declarative_base()


class TaskRequest(Base):
    __tablename__ = 'task_requests'

    uuid = Column(UUID(as_uuid=True), primary_key=True, default=uuid4)

    task_uuid = Column(UUID(as_uuid=True), ForeignKey(TaskModel.uuid), nullable=False, index=True)
    task = relationship(TaskModel, back_populates="requests")

    result = relationship(TaskResultModel, uselist=False, back_populates="task_request")

    statuses = relationship(TaskStatusModel, back_populates="task_request")

    data = Column(JSON)

    callback = Column(TEXT)

    created_at = Column(TIMESTAMP, server_default=func.current_timestamp())
    updated_at = Column(TIMESTAMP, onupdate=func.current_timestamp())
