from sqlalchemy import Column, func, ForeignKey
from sqlalchemy.orm import relationship
from sqlalchemy.dialects.postgresql import UUID, VARCHAR, JSON, TIMESTAMP
from uuid import uuid4
from sqlalchemy.ext.declarative import declarative_base

from .task_requests import TaskRequest as TaskRequestModel

Base = declarative_base()


class TaskResult(Base):
    __tablename__ = "task_results"

    uuid = Column(UUID(as_uuid=True), primary_key=True, default=uuid4)

    task_request_uuid = Column(UUID(as_uuid=True), ForeignKey(TaskRequestModel.uuid), nullable=False, unique=True)
    task_request = relationship(TaskRequestModel, back_populates="result")

    status = Column(VARCHAR(50), index=True)
    data = Column(JSON)

    created_at = Column(TIMESTAMP, server_default=func.current_timestamp())
